# Generated by Django 3.2.13 on 2022-05-19 03:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='fingerprint',
            field=models.TextField(blank=True),
        ),
    ]
